Crate wind_tunnel_summary_model

Crate wind_tunnel_summary_model 

Structs

BuildInfo
Build information of any software used in the run. This is expected to be specific to the binding used by a scenario.
RunSummary
Summary of a run
RunSummaryInitArgs
Arguments for initializing a RunSummary

Functions

append_run_summary
Append the run summary to a file
load_run_summary
Load a run summary from a reader
load_summary_runs
Load run summaries from a file
store_run_summary
Serialize the run summary to a writer