Structs
- Build
Info - Build information of any software used in the run. This is expected to be specific to the binding used by a scenario.
- RunSummary
- Summary of a run
- RunSummary
Init Args - Arguments for initializing a
RunSummary
Functions
- append_
run_ summary - Append the run summary to a file
- load_
run_ summary - Load a run summary from a reader
- load_
summary_ runs - Load run summaries from a file
- store_
run_ summary - Serialize the run summary to a writer